'use strict';
/*
 * This job reads files from config.articlesLocation and loads this list to `pages`
 */
var walk = require('walk');
var fs = require('fs');
var path = require('path');

module.exports = function(obj) {
  console.log('Build step: ReadFiles');
  var onFile = function(root, fileStats, next, array) {
    var filename = path.join(root,fileStats.name);
    var file = path.relative(obj.config.sourceDir, filename);
    fs.readFile(filename, 'utf8', function(err,data) {
      if(err) {
        console.log('Error reading file '+filename)
        console.log(err);
      } else {
        array.push({
          filename: filename,
          file: file,
          content: data
        })
      }
      next()
    })
  };

  var promise1 = new Promise(function(resolve, reject) {
    var pages = [];
    walk.walk(path.join(obj.config.sourceDir,obj.config.articlesLocation))
    .on('file',function(root,fileStats,next) {
      onFile(root,fileStats,next,pages);
    })
    .on('errors',function(root, nodeStatsArray, next) {
      console.log('Walker error', root, nodeStatsArray);
      next();
    })
    .on('end', function() {
      resolve({type: 'pages', val: pages});
    })
  })

  var promise2 = new Promise(function(resolve, reject) {
    let redirects = [];
    walk.walk(path.join(obj.config.sourceDir,obj.config.redirectsLocation))
    .on('file',function(root,fileStats,next) {
      onFile(root,fileStats,next,redirects);
    })
    .on('errors',function(root, nodeStatsArray, next) {
      console.log('Walker error', root, nodeStatsArray);
      next();
    })
    .on('end', function() {
      resolve({type: 'redirects', val: redirects});
    })
  })
  return Promise.all([promise1,promise2]).then(function(arr) {
    arr.forEach(function(v) {
      obj[v.type] = v.val;
    });
    return obj;
  });
}
